@@ -1,13 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2022 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.41;
+use Object::Pad 0.57;
 
-package Tangence::Compiler::Parser 0.27;
-class Tangence::Compiler::Parser isa Parser::MGC;
+package Tangence::Compiler::Parser 0.29;
+class Tangence::Compiler::Parser :isa(Parser::MGC);
 
 use Syntax::Keyword::Dynamically;
 use Syntax::Keyword::Match;
